cbindQTLeffects: Combine multiple runs of estQTLeffects

View source: R/estQTLeffects.R

cbindQTLeffectsR Documentation

Combine multiple runs of estQTLeffects

Description

Combine multiple runs of estQTLeffects by applying cbind to each component

Usage

cbindQTLeffects(..., labels)

Arguments

...

Results of estQTLeffects()

labels

Vector of labels to use in the combination.

Value

list of matrices; each component corresponds to a position in the genome and is a matrix with phenotypes x effects

See Also

estQTLeffects()

Examples

library(qtl)
data(fake.f2)
fake.f2 <- calc.genoprob(fake.f2)
sex <- fake.f2$pheno$sex
eff.fem <- estQTLeffects(fake.f2[,sex==0], pheno.col=1)
eff.mal <- estQTLeffects(fake.f2[,sex==1], pheno.col=1)
eff <- cbindQTLeffects(eff.fem, eff.mal, labels=c("female", "male"))


qtlcharts documentation built on June 19, 2026, 5:07 p.m.