| idotplot | R Documentation |
Creates an interactive graph of phenotypes vs genotypes at a marker.
idotplot(
x,
y,
indID = NULL,
group = NULL,
horizontal = FALSE,
chartOpts = NULL,
digits = 5
)
x |
Vector of groups of individuals (e.g., a genotype) |
y |
Numeric vector (e.g., a phenotype) |
indID |
Optional vector of character strings, shown with tool tips |
group |
Optional vector of categories for coloring points |
horizontal |
If TRUE, switch role of x- and y-axes and have quantitative variable on x-axis. |
chartOpts |
A list of options for configuring the chart. Each element must be named using the corresponding option. |
digits |
Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.) |
An object of class htmlwidget that will
intelligently print itself into HTML in a variety of contexts
including the R console, within R Markdown documents, and within
Shiny output bindings.
iplot(), iplotPXG()
n <- 100
g <- sample(LETTERS[1:3], n, replace=TRUE)
y <- rnorm(n, match(g, LETTERS[1:3])*10, 5)
idotplot(g, y)
idotplot(g, y, horizontal=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.