| iplotMap | R Documentation |
Creates an interactive graph of a genetic marker map.
iplotMap(
map,
chr = NULL,
shift = FALSE,
horizontal = FALSE,
chartOpts = NULL,
digits = 5
)
map |
Object of class |
chr |
(Optional) Vector indicating the chromosomes to plot. |
shift |
If TRUE, shift each chromsome so that the initial marker is at position 0. |
horizontal |
If TRUE, have chromosomes arranged horizontally |
chartOpts |
A list of options for configuring the chart. Each element must be named using the corresponding option. |
digits |
Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.) |
An object of class htmlwidget that will
intelligently print itself into HTML in a variety of contexts
including the R console, within R Markdown documents, and within
Shiny output bindings.
iplotScanone(), iplotPXG()
library(qtl)
data(hyper)
map <- pull.map(hyper)
iplotMap(map, shift=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.