iplotRF: Interactive plot of recombination fractions

View source: R/iplotRF.R

iplotRFR Documentation

Interactive plot of recombination fractions

Description

Creates an interactive graph of estimated recombination fractions and LOD scores for all pairs of markers.

Usage

iplotRF(cross, chr = NULL, chartOpts = NULL, digits = 5)

Arguments

cross

Object of class "cross", see qtl::read.cross().

chr

Optional vector indicating chromosomes to include. This should be a vector of character strings referring to chromosomes by name; numeric values are converted to strings. Refer to chromosomes with a preceding - to have all chromosomes but those considered. A logical (TRUE/FALSE) vector may also be used.

chartOpts

A list of options for configuring the chart. Each element must be named using the corresponding option.

digits

Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.)

Details

The heatmap in the plot just depicts the LOD scores for
testing rf=0.5.

Value

An object of class htmlwidget that will intelligently print itself into HTML in a variety of contexts including the R console, within R Markdown documents, and within Shiny output bindings.

See Also

qtl::est.rf(), qtl::plotRF()

Examples

library(qtl)
data(fake.f2)

fake.f2 <- est.rf(fake.f2)

iplotRF(fake.f2)


qtlcharts documentation built on June 19, 2026, 5:07 p.m.