iplotScantwo: Interactive plot of 2d genome scan

View source: R/iplotScantwo.R

iplotScantwoR Documentation

Interactive plot of 2d genome scan

Description

Creates an interactive plot of the results of qtl::scantwo(), for a two-dimensional, two-QTL genome scan.

Usage

iplotScantwo(
  scantwoOutput,
  cross = NULL,
  lodcolumn = 1,
  pheno.col = 1,
  chr = NULL,
  chartOpts = NULL,
  digits = 5
)

Arguments

scantwoOutput

Output of qtl::scantwo()

cross

(Optional) Object of class "cross", see qtl::read.cross().

lodcolumn

Numeric value indicating LOD score column to plot.

pheno.col

(Optional) Phenotype column in cross object.

chr

(Optional) Optional vector indicating the chromosomes for which LOD scores should be calculated. This should be a vector of character strings referring to chromosomes by name; numeric values are converted to strings. Refer to chromosomes with a preceding - to have all chromosomes but those considered. A logical (TRUE/FALSE) vector may also be used.

chartOpts

A list of options for configuring the chart. Each element must be named using the corresponding option.

digits

Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.)

Details

The estimated QTL effects, and the genotypes in the phenotype x genotype plot, in the right-hand panels, are derived following a single imputation to fill in missing data, and so are a bit crude.

Note that the usual height and width options in chartOpts are ignored here. Instead, you may provide pixelPerCell (number of pixels per cell in the heat map), chrGap (gaps between chr in heat map), wright (width in pixels of right panels), and hbot (height in pixels of each of the lower panels)

Value

An object of class htmlwidget that will intelligently print itself into HTML in a variety of contexts including the R console, within R Markdown documents, and within Shiny output bindings.

See Also

iplotScanone()

Examples

library(qtl)
data(fake.f2)

fake.f2 <- calc.genoprob(fake.f2, step=5)
out <- scantwo(fake.f2, method="hk", verbose=FALSE)

iplotScantwo(out, fake.f2)


qtlcharts documentation built on June 19, 2026, 5:07 p.m.