itimeplot: Interactive scatterplot with date/time on x-axis

View source: R/itimeplot.R

itimeplotR Documentation

Interactive scatterplot with date/time on x-axis

Description

Creates an interactive scatterplot with date/time on the x-axis.

Usage

itimeplot(
  datetime,
  y,
  group = NULL,
  indID = NULL,
  chartOpts = NULL,
  digits = 5
)

Arguments

datetime

Vector of date/time values

y

Numeric vector of y values

group

Optional vector of categories for coloring the points

indID

Optional vector of character strings, shown with tool tips

chartOpts

A list of options for configuring the chart. Each element must be named using the corresponding option.

digits

Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.)

Value

An object of class htmlwidget that will intelligently print itself into HTML in a variety of contexts including the R console, within R Markdown documents, and within Shiny output bindings.

See Also

iplotCorr(), iplotCurves(), itriplot(), idotplot(), iplotPXG()

Examples

n_pts <- 100
x <-  seq(as.POSIXct("1969-05-01"), as.POSIXct("1969-05-04"), length=n_pts)
grp <- sample(1:3, n_pts, replace=TRUE)
y <- rnorm(n_pts, grp) + rnorm(n_pts)

itimeplot(x, y, grp)


# with shorter time span, times are shown instead of dates
x <-  seq(as.POSIXct("1969-05-01"), as.POSIXct("1969-05-02"), length=n_pts)

itimeplot(x, y, grp, chartOpts=list(xlab="Time"))

#'

qtlcharts documentation built on June 19, 2026, 5:07 p.m.