qtlcharts-package: R/qtlcharts: Interactive charts for QTL data

qtlcharts-packageR Documentation

R/qtlcharts: Interactive charts for QTL data

Description

A QTL is a quantitative trait locus: a genetic locus that contributes to variation in a quantitative trait. The goal of R/qtlcharts is to provide interactive data visualizations for QTL analyses, and to make these visualizations available from R. It is a companion to the R/qtl package.

Details

Vignettes online at the R/qtlcharts website:

Author(s)

Maintainer: Karl W Broman broman@wisc.edu (ORCID)

Authors:

Other contributors:

  • Michael Bostock (d3.js library in htmlwidgets/lib, https://d3js.org) [contributor, copyright holder]

  • jQuery Foundation (jQuery library in htmlwidgets/lib, https://jquery.com) [copyright holder]

  • jQuery contributors (jQuery library in htmlwidgets/lib; see https://github.com/jquery/jquery/blob/master/AUTHORS.txt) [contributor]

  • jQuery UI contributors (jQuery UI library in htmlwidgets/lib; see https://jqueryui.com/about/) [contributor]

See Also

Useful links:


qtlcharts documentation built on June 19, 2026, 5:07 p.m.