qtlcharts-shiny: Shiny bindings for R/qtlcharts widgets

qtlcharts-shinyR Documentation

Shiny bindings for R/qtlcharts widgets

Description

Output and render functions for using R/qtlcharts widgets within Shiny applications and interactive Rmd documents. For examples, see https://github.com/kbroman/shiny_qtlcharts.

Usage

iboxplot_output(outputId, width = "100%", height = "900")

iboxplot_render(expr, env = parent.frame(), quoted = FALSE)

idotplot_output(outputId, width = "100%", height = "530")

idotplot_render(expr, env = parent.frame(), quoted = FALSE)

iheatmap_output(outputId, width = "100%", height = "1000")

iheatmap_render(expr, env = parent.frame(), quoted = FALSE)

ipleiotropy_output(outputId, width = "100%", height = "580")

ipleiotropy_render(expr, env = parent.frame(), quoted = FALSE)

iplot_output(outputId, width = "100%", height = "580")

iplot_render(expr, env = parent.frame(), quoted = FALSE)

iplotCorr_output(outputId, width = "100%", height = "1000")

iplotCorr_render(expr, env = parent.frame(), quoted = FALSE)

iplotCurves_output(outputId, width = "100%", height = "1000")

iplotCurves_render(expr, env = parent.frame(), quoted = FALSE)

iplotMScanone_output(outputId, width = "100%", height = "580")

iplotMScanone_render(expr, env = parent.frame(), quoted = FALSE)

iplotMap_output(outputId, width = "100%", height = "680")

iplotMap_render(expr, env = parent.frame(), quoted = FALSE)

iplotRF_output(outputId, width = "100%", height = "1000")

iplotRF_render(expr, env = parent.frame(), quoted = FALSE)

iplotScanone_output(outputId, width = "100%", height = "580")

iplotScanone_render(expr, env = parent.frame(), quoted = FALSE)

iplotScantwo_output(outputId, width = "100%", height = "1000")

iplotScantwo_render(expr, env = parent.frame(), quoted = FALSE)

itimeplot_output(outputId, width = "100%", height = "580")

itimeplot_render(expr, env = parent.frame(), quoted = FALSE)

itriplot_output(outputId, width = "100%", height = "530")

itriplot_render(expr, env = parent.frame(), quoted = FALSE)

scat2scat_output(outputId, width = "100%", height = "530")

scat2scat_render(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like "100\%", "400px", "auto") or a number, which will be coerced to a string and have "px" appended.

expr

An expression that generates the graph.

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.


qtlcharts documentation built on June 19, 2026, 5:07 p.m.