View source: R/estQTLeffects.R
| estQTLeffects | R Documentation |
Calculates the effects of QTL at each position across the genome
using Haley-Knott regression, much like qtl::effectscan(),
but considering multiple phenotypes and not plotting the results
estQTLeffects(cross, pheno.col = 1, what = c("means", "effects"))
cross |
(Optional) Object of class |
pheno.col |
Phenotype columns in cross object. |
what |
Indicates whether to calculate phenotype averages for each genotype group or to turn these into additive and dominance effects. |
One should first run qtl::calc.genoprob();
if not, it is run with the default arguments.
The estimated effects will be poorly estimated in the case of selective genotyping, as Haley-Knott regression performs poorly in this case.
list of matrices; each component corresponds to a position in the genome and is a matrix with phenotypes x effects
iplotMScanone(), qtl::effectscan()
cbindQTLeffects()
data(grav)
library(qtl)
grav <- reduce2grid(calc.genoprob(grav, step=1))
out <- estQTLeffects(grav, phe=seq(1, nphe(grav), by=5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.