| iplotPXG | R Documentation |
Creates an interactive graph of phenotypes vs genotypes at a marker.
iplotPXG(
cross,
marker,
pheno.col = 1,
horizontal = FALSE,
chartOpts = NULL,
fillgenoArgs = NULL,
digits = 5
)
cross |
Object of class |
marker |
Character string with marker name. |
pheno.col |
Phenotype column in cross object. |
horizontal |
If TRUE, switch role of x- and y-axes and put genotype on y-axis. |
chartOpts |
A list of options for configuring the chart. Each element must be named using the corresponding option. |
fillgenoArgs |
List of named arguments to pass to
|
digits |
Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.) |
The function qtl::fill.geno() is used to
impute missing genotypes, with arguments passed as a list, for
example fillgenoArgs=list(method="argmax", error.prob=0.002, map.function="c-f").
Individual IDs (viewable when hovering over a point) are taken from
the input cross object, using the qtl::getid()
function in R/qtl.
By default, points are colored blue and pink according to whether the marker genotype is observed or inferred, respectively.
An object of class htmlwidget that will
intelligently print itself into HTML in a variety of contexts
including the R console, within R Markdown documents, and within
Shiny output bindings.
idotplot(), iplot(), iplotScanone(),
iplotMap()
library(qtl)
data(hyper)
marker <- sample(markernames(hyper), 1)
iplotPXG(hyper, marker)
# different colors
iplotPXG(hyper, marker, chartOpts=list(pointcolor=c("black", "gray")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.