| iplotRF | R Documentation |
Creates an interactive graph of estimated recombination fractions and LOD scores for all pairs of markers.
iplotRF(cross, chr = NULL, chartOpts = NULL, digits = 5)
cross |
Object of class |
chr |
Optional vector indicating chromosomes to include. This
should be a vector of character strings referring to chromosomes by
name; numeric values are converted to strings. Refer to
chromosomes with a preceding |
chartOpts |
A list of options for configuring the chart. Each element must be named using the corresponding option. |
digits |
Round data to this number of significant digits before passing to the chart function. (Use NULL to not round.) |
The heatmap in the plot just depicts the LOD scores for testing rf=0.5.
An object of class htmlwidget that will
intelligently print itself into HTML in a variety of contexts
including the R console, within R Markdown documents, and within
Shiny output bindings.
qtl::est.rf(), qtl::plotRF()
library(qtl)
data(fake.f2)
fake.f2 <- est.rf(fake.f2)
iplotRF(fake.f2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.