| qtlcharts-package | R Documentation |
A QTL is a quantitative trait locus: a genetic locus that contributes to variation in a quantitative trait. The goal of R/qtlcharts is to provide interactive data visualizations for QTL analyses, and to make these visualizations available from R. It is a companion to the R/qtl package.
Vignettes online at the R/qtlcharts website:
Maintainer: Karl W Broman broman@wisc.edu (ORCID)
Authors:
Karl W Broman broman@wisc.edu (ORCID)
Other contributors:
Michael Bostock (d3.js library in htmlwidgets/lib, https://d3js.org) [contributor, copyright holder]
jQuery Foundation (jQuery library in htmlwidgets/lib, https://jquery.com) [copyright holder]
jQuery contributors (jQuery library in htmlwidgets/lib; see https://github.com/jquery/jquery/blob/master/AUTHORS.txt) [contributor]
jQuery UI contributors (jQuery UI library in htmlwidgets/lib; see https://jqueryui.com/about/) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.